@@ -148,8 +148,10 @@ def drain_consumer(consumer, limit=1, timeout=None, callbacks=None):
 
 def itermessages(conn, channel, queue, limit=1, timeout=None,
                  callbacks=None, **kwargs):
-    return drain_consumer(conn.Consumer(channel, queues=[queue], **kwargs),
-                          limit=limit, timeout=timeout, callbacks=callbacks)
+    return drain_consumer(
+        conn.Consumer(queues=[queue], channel=channel, **kwargs),
+        limit=limit, timeout=timeout, callbacks=callbacks,
+    )
 
 
 def eventloop(conn, limit=None, timeout=None, ignore_timeouts=False):
